@@ -33,8 +33,6 @@
 #include "goafacebookprovider.h"
 #include "goaimapsmtpprovider.h"
 #include "goaowncloudprovider.h"
-#include "goayahooprovider.h"
-#include "goatwitterprovider.h"
 #include "goaflickrprovider.h"
 #include "goawindowsliveprovider.h"
 
@@ -685,12 +683,6 @@ ensure_builtins_loaded (void)
 #ifdef GOA_KERBEROS_ENABLED
       type = GOA_TYPE_KERBEROS_PROVIDER;
 #endif
-#ifdef GOA_YAHOO_ENABLED
-      type = GOA_TYPE_YAHOO_PROVIDER;
-#endif
-#ifdef GOA_TWITTER_ENABLED
-      type = GOA_TYPE_TWITTER_PROVIDER;
-#endif
 
       type = type; /* silence -Wunused-but-set-variable */
 
